@@ -5,14 +5,14 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy           (); 
-use Carp                  ();
-use Sub::Uplevel          ();
-use Aspect::Advice        ();
-use Aspect::Advice::Hook  ();
-use Aspect::AdviceContext ();
+use Carp::Heavy                     (); 
+use Carp                            ();
+use Sub::Uplevel                    ();
+use Aspect::Hook                    ();
+use Aspect::Advice                  ();
+use Aspect::Context::AfterReturning ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
 our @ISA     = 'Aspect::Advice';
 
 # NOTE: To simplify debugging of the generated code, all injected string
@@ -28,7 +28,7 @@ sub _install {
 	# runtime checks instead of the original.
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
-	my $curried   = $pointcut->curry_run;
+	my $curried   = $pointcut->match_curry;
 	my $MATCH_RUN = $curried ? '$curried->match_run($runtime)' : 1;
 
 	# When an aspect falls out of scope, we don't attempt to remove
@@ -62,34 +62,35 @@ sub _install {
 		# Generate the new function
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
-		package Aspect::Advice::Hook;
+		package Aspect::Hook;
 
 		*$NAME = sub $PROTOTYPE {
 			# Is this a lexically scoped hook that has finished
 			goto &\$original if $MATCH_DISABLED;
 
 			my \$wantarray = wantarray;
-			my \$runtime   = {
-				sub_name  => \$name,
-				wantarray => \$wantarray,
-			};
 			if ( \$wantarray ) {
 				my \$return = [
 					Sub::Uplevel::uplevel(
 						1, \$original, \@_,
 					)
 				];
+				my \$runtime = {
+					type         => 'after_returning',
+					sub_name     => \$name,
+					wantarray    => \$wantarray,
+					params       => \\\@_,
+					return_value => \$return,
+					exception    => undef,
+				};
 				return \@\$return unless $MATCH_RUN;
 
 				# Create the context
-				my \$context = Aspect::AdviceContext->new(
-					type         => 'after_returning',
-					pointcut     => \$pointcut,
-					params       => \\\@_,
-					return_value => \$return,
-					original     => \$original,
+				my \$context = bless {
+					pointcut => \$pointcut,
+					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::AfterReturning';
 
 				# Execute the advice code
 				() = &\$code(\$context);
@@ -102,18 +103,22 @@ sub _install {
 				my \$return = Sub::Uplevel::uplevel(
 					1, \$original, \@_,
 				);
-				return \$return unless $MATCH_RUN;
-
-				# Create the context
-				my \$context = Aspect::AdviceContext->new(
+				my \$runtime = {
 					type         => 'after_returning',
-					pointcut     => \$pointcut,
+					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => \$return,
-					original     => \$original,
+					exception    => undef,
+				};
+				return \$return unless $MATCH_RUN;
+
+				# Create the context
+				my \$context = bless {
+					pointcut => \$pointcut,
+					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::AfterReturning';
 
 				# Execute the advice code
 				my \$dummy = &\$code(\$context);
@@ -123,18 +128,22 @@ sub _install {
 				Sub::Uplevel::uplevel(
 					1, \$original, \@_,
 				);
-				return unless $MATCH_RUN;
-
-				# Create the context
-				my \$context = Aspect::AdviceContext->new(
+				my \$runtime = {
 					type         => 'after_returning',
-					pointcut     => \$pointcut,
+					sub_name     => \$name,
 					wantarray    => \$wantarray,
 					params       => \\\@_,
 					return_value => undef,
-					original     => \$original,
+					exception    => undef,
+				};
+				return unless $MATCH_RUN;
+
+				# Create the context
+				my \$context = bless {
+					pointcut => \$pointcut,
+					original => \$original,
 					\%\$runtime,
-				);
+				}, 'Aspect::Context::AfterReturning';
 
 				# Execute the advice code
 				&\$code(\$context);
