@@ -5,14 +5,14 @@ use warnings;
 
 # Added by eilara as hack around caller() core dump
 # NOTE: Now we've switched to Sub::Uplevel can this be removed? --ADAMK
-use Carp::Heavy           (); 
-use Carp                  ();
-use Sub::Uplevel          ();
-use Aspect::Advice        ();
-use Aspect::Advice::Hook  ();
-use Aspect::AdviceContext ();
+use Carp::Heavy             (); 
+use Carp                    ();
+use Sub::Uplevel            ();
+use Aspect::Hook            ();
+use Aspect::Advice          ();
+use Aspect::Context::Around ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
 our @ISA     = 'Aspect::Advice';
 
 sub _install {
@@ -25,7 +25,7 @@ sub _install {
 	# runtime checks instead of the original.
 	# Because $MATCH_RUN is used in boolean conditionals, if there
 	# is nothing to do the compiler will optimise away the code entirely.
-	my $curried   = $pointcut->curry_run;
+	my $curried   = $pointcut->match_curry;
 	my $MATCH_RUN = $curried ? '$curried->match_run($runtime)' : 1;
 
 	# When an aspect falls out of scope, we don't attempt to remove
@@ -59,7 +59,7 @@ sub _install {
 		# Generate the new function
 		no warnings 'redefine';
 		eval <<"END_PERL"; die $@ if $@;
-		package Aspect::Advice::Hook;
+		package Aspect::Hook;
 
 		*$NAME = sub $PROTOTYPE {
 			# Is this a lexically scoped hook that has finished
@@ -68,20 +68,21 @@ sub _install {
 			# Apply any runtime-specific context checks
 			my \$wantarray = wantarray;
 			my \$runtime   = {
+				type      => 'around',
 				sub_name  => \$name,
 				wantarray => \$wantarray,
+				params    => \\\@_,
 			};
 			goto &\$original unless $MATCH_RUN;
 
 			# Prepare the context object
-			my \$context   = Aspect::AdviceContext->new(
-				type         => 'around',
-				pointcut     => \$pointcut,
-				params       => \\\@_,
+			my \$context = bless {
 				return_value => \$wantarray ? [ ] : undef,
+				exception    => undef,
+				pointcut     => \$pointcut,
 				original     => \$original,
 				\%\$runtime,
-			);
+			}, 'Aspect::Context::Around';
 
 			# Array context needs some special return handling
 			if ( \$wantarray ) {
