@@ -7,7 +7,7 @@ use Aspect::Pointcut::Or  ();
 use Aspect::Pointcut::And ();
 use Aspect::Pointcut::Not ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
 
 use overload (
 	# Keep traditional Perl boolification and stringification
@@ -70,6 +70,10 @@ BEGIN {
 	);
 }
 
+sub match_runtime {
+	return 1;
+}
+
 # Find the list of all matching subs
 sub match_all {
 	my $self    = shift;
@@ -83,7 +87,8 @@ sub match_all {
 		next if $UNTOUCHABLE{$package};
 		next if $package =~ /^Aspect\b/;
 		foreach my $name ( Devel::Symdump->new($package)->functions ) {
-			# TODO: Need to filter Aspect exportable functions!
+			# Filter Aspect exportable functions
+			next if $Aspect::EXPORTED{$name};
 			push @matches, $name if $self->match_define($name);
 		}
 	}
@@ -102,7 +107,7 @@ sub match_contains {
 	return '';
 }
 
-sub curry_run {
+sub match_curry {
 	my $class = ref $_[0] || $_[0];
 	die("Method 'curry' not implemented in class '$class'");
 }
