@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Aspect::Pointcut ();
 
-our $VERSION = '0.41';
+our $VERSION = '0.43';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -21,7 +21,7 @@ sub match_define {
 
 # The condition pointcut contains no state and doesn't need to be curried.
 # Simply return it as-is and reuse it everywhere.
-sub curry_run {
+sub match_curry {
 	return $_[0];
 }
 
