@@ -6,7 +6,7 @@ use Carp             ();
 use Params::Util     ('_STRING', '_INSTANCE');
 use Aspect::Pointcut ();
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 our @ISA     = 'Aspect::Pointcut';
 
 
@@ -23,7 +23,7 @@ sub match_define {
 # Call pointcuts curry away to null, because they are the basis
 # for which methods to hook in the first place. Any method called
 # at run-time has already been checked.
-sub curry_run {
+sub match_curry {
 	return $_[0];
 }
 
